@@ -343,6 +343,8 @@ class Cursor(common.DBAPICursor):
             if len(self._batch) == 0:
                 return None
         self._rownumber += len(self._batch)
+        _logger.info("Row Number: ", self._rownumber)
+        _logger.info("lenght of batch: ", len(self._batch))
         if self._rownumber <= 1000:
             _logger.info("e6x - Breaking the loop after 1000 e6x - fetch many records")
             return self._batch
